Distance class

Constructors

Distance.fixed(int fixedDistance)
factory
Distance.proportional(double proportionalDistance)
factory

Properties

fixedDistance → int
final
hashCode → int
The hash code for this object.
no setterinherited
isFixedDistance → bool
final
proportionalDistance → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateFixedDistance(double width, double height, double angle) → int
Calculates the fixed distance based on the rectangle and angle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(String s) → Distance
Parse a distance from a string

Constants

downAngle → const double
upAngle → const double