WidgetProperty enum

Enum for common widget properties.

Inheritance
Available extensions

Values

knownControlClass → const WidgetProperty
className → const WidgetProperty
enabled → const WidgetProperty
text → const WidgetProperty
textColor → const WidgetProperty
checked → const WidgetProperty
pressed → const WidgetProperty
checkState → const WidgetProperty
hasFocus → const WidgetProperty
selectedItemText → const WidgetProperty
selectedItemIndex → const WidgetProperty
selectionStart → const WidgetProperty
selectionLength → const WidgetProperty
backgroundColor → const WidgetProperty
containerType → const WidgetProperty
top → const WidgetProperty
left → const WidgetProperty
width → const WidgetProperty
height → const WidgetProperty
screenY → const WidgetProperty
screenX → const WidgetProperty
visible → const WidgetProperty
visibility → const WidgetProperty
id → const WidgetProperty
parentId → const WidgetProperty
flutterElement → const WidgetProperty
selectionText → const WidgetProperty
value → const WidgetProperty
minValue → const WidgetProperty
maxValue → const WidgetProperty
sliderCurrentValue → const WidgetProperty
selected → const WidgetProperty
image → const WidgetProperty
title → const WidgetProperty
tabIndex → const WidgetProperty
caption → const WidgetProperty
accessibilityLabel → const WidgetProperty
accessibilityId → const WidgetProperty
contentOffsetX → const WidgetProperty
contentOffsetY → const WidgetProperty
toggleButtonState → const WidgetProperty

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name → String

Available on WidgetProperty, provided by the WidgetPropertyExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<WidgetProperty>
A constant List of the values in this enum, in order of their declaration.